@@ -1,7 +1,7 @@
 /*
  * kdfwidget.cpp
  *
- * $Id: kdfwidget.cpp,v 1.25 2001/03/12 13:36:29 mike Exp $
+ * $Id: kdfwidget.cpp,v 1.29 2001/12/18 15:23:18 binner Exp $
  *
  * Copyright (c) 1998-2001 Michael Kropfberger <michael.kropfberger@gmx.net>
  *
@@ -22,7 +22,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
- 
+
 //
 // 1999-11-29 Espen Sand
 // Converted to QLayout and QListView + cleanups
@@ -32,19 +32,13 @@
 
 #include <stdlib.h>
 
-#include <qbitmap.h>
 #include <qheader.h>
-#include <qpixmap.h>
-#include <qpaintdevice.h>
-#include <qstring.h> 
 #include <qtimer.h>
 #include <qlayout.h>
+#include <qpainter.h>
 
-#include <kdebug.h>
-#include <kapp.h> 
+#include <kapplication.h>
 #include <kcmenumngr.h>
-#include <kglobal.h>
-#include <kiconloader.h>
 #include <kmessagebox.h>
 #include <kpopupmenu.h>
 
@@ -69,7 +63,7 @@ CListViewItem::CListViewItem( CListView * parent, QListViewItem * after )
 
 // 2001-03-10 Walter F.J. Mueller <W.F.J.Mueller@gsi.de>
 // This method returns for all numeric columns the converted number.
-// The conversion is done with 
+// The conversion is done with
 //    1. fixed position of the colon
 //    2. a sufficient number of leading blanks
 // This ensures that the lexical string comparison gives numerical order.
@@ -138,10 +132,10 @@ KDFWidget::KDFWidget( QWidget *parent, const char *name, bool init )
     mList->setAllColumnsShowFocus( true );
     mList->setFrameStyle( QFrame::WinPanel + QFrame::Sunken );
     mList->setShowSortIndicator(true);
-    connect( mList, 
+    connect( mList,
       SIGNAL( pressed( QListViewItem *, const QPoint &, int )),
       this, SLOT( rightButtonPressed( QListViewItem *, const QPoint &, int )));
-    connect( mList, 
+    connect( mList,
       SIGNAL( clicked( QListViewItem *, const QPoint &, int )),
       this, SLOT( rightButtonClicked( QListViewItem *, const QPoint &, int )));
     connect( mList->header(), SIGNAL(sizeChange(int, int, int)),
@@ -159,9 +153,9 @@ KDFWidget::KDFWidget( QWidget *parent, const char *name, bool init )
 }
 
 
-KDFWidget::~KDFWidget() 
+KDFWidget::~KDFWidget()
 {
-} 
+}
 
 
 
@@ -202,7 +196,7 @@ void KDFWidget::makeColumns( void )
 /******************************************************************/
 void KDFWidget::closeEvent(QCloseEvent *)
 {
-  applySettings(); 
+  applySettings();
   kapp->quit();
 };
 
@@ -222,12 +216,12 @@ void KDFWidget::applySettings( void )
   KConfig &config = *kapp->config();
 
   config.setGroup("KDiskFree");
-  if( mIsTopLevel == true ) 
+  if( mIsTopLevel == true )
   {
     config.writeEntry( "Width", width() );
     config.writeEntry( "Height", height() );
   }
-  if( GUI ) 
+  if( GUI )
   {
     for( uint i=0; i<mTabProp.size(); i++ )
     {
@@ -251,7 +245,7 @@ void KDFWidget::loadSettings( void )
 {
   mStd.updateConfiguration();
 
-  if(GUI) 
+  if(GUI)
   {
     KConfig &config = *kapp->config();
     config.setGroup("KDiskFree");
@@ -267,7 +261,7 @@ void KDFWidget::loadSettings( void )
       CTabEntry &e = *mTabProp[i];
       e.mWidth = config.readNumEntry( e.mRes, e.mWidth );
     }
-    if (mTabProp[usageCol]->mWidth > 16) 
+    if (mTabProp[usageCol]->mWidth > 16)
       mTabProp[usageCol]->mWidth -= 16;
 
     config.setGroup("KDFConfig");
@@ -289,13 +283,13 @@ void KDFWidget::loadSettings( void )
 **/
 void KDFWidget::settingsBtnClicked( void )
 {
-  if( mIsTopLevel == true ) 
+  if( mIsTopLevel == true )
   {
     if( mOptionDialog == 0 )
     {
       mOptionDialog = new COptionDialog( this, "options", false );
       if( mOptionDialog == 0 ) { return; }
-      connect( mOptionDialog, SIGNAL(valueChanged()), 
+      connect( mOptionDialog, SIGNAL(valueChanged()),
 	       this, SLOT(settingsChanged()) );
     }
     mOptionDialog->show();
@@ -322,14 +316,14 @@ void KDFWidget::setUpdateFrequency( int frequency )
 /***************************************************************************
   * Update (reread) all disk-dependencies
 **/
-void KDFWidget::timerEvent(QTimerEvent *) 
+void KDFWidget::timerEvent(QTimerEvent *)
 {
   updateDF();
 }
 
 
 /***************************************************************************
-  * checks fstab & df 
+  * checks fstab & df
 **/
 void KDFWidget::updateDF( void )
 {
@@ -340,7 +334,7 @@ void KDFWidget::updateDF( void )
   {
     readingDF = TRUE;
     mDiskList.readFSTAB();
-    mDiskList.readDF(); 
+    mDiskList.readDF();
   }
 }
 
@@ -353,11 +347,11 @@ void KDFWidget::updateDFDone( void ){
 
   int i=0;
   CListViewItem *item = 0;
-  for( DiskEntry *disk=mDiskList.first(); disk!=0; disk=mDiskList.next() ) 
+  for( DiskEntry *disk=mDiskList.first(); disk!=0; disk=mDiskList.next() )
   {
     i++;
     QString size, percent;
-    if( disk->kBSize() > 0 ) 
+    if( disk->kBSize() > 0 )
     {
       percent = KGlobal::locale()->formatNumber(disk->percentFull(), 1) + '%';
       size = disk->prettyKBSize();
@@ -395,7 +389,7 @@ void KDFWidget::resizeEvent( QResizeEvent * )
 }
 
 
- 
+
 /**************************************************************************
   * connected with diskList
 **/
@@ -483,14 +477,14 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
   }
 
   //
-  // The list update will be disabled as long as this menu is 
-  // visible. Reason: The 'disk' may no longer be valid. 
+  // The list update will be disabled as long as this menu is
+  // visible. Reason: The 'disk' may no longer be valid.
   //
   mPopup = new KPopupMenu( disk->mountPoint(), 0 );
-  mPopup->insertItem( i18n("Mount device"), 0 );
-  mPopup->insertItem( i18n("Unmount device"), 1 );
+  mPopup->insertItem( i18n("Mount Device"), 0 );
+  mPopup->insertItem( i18n("Unmount Device"), 1 );
   mPopup->insertSeparator();
-  mPopup->insertItem( i18n("Open filemanager"), 2 );
+  mPopup->insertItem( i18n("Open Filemanager"), 2 );
   mPopup->setItemEnabled( 0, disk->mounted() ? false : true );
   mPopup->setItemEnabled( 1, disk->mounted() );
   mPopup->setItemEnabled( 2, disk->mounted() );
@@ -508,7 +502,7 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
       item->setText( sizeCol, i18n("MOUNTING") );
       item->setText( freeCol, i18n("MOUNTING") );
       item->setPixmap( 0, mList->icon( "mini-clock", false ) );
-      
+
       int val = disk->toggleMount();
       if( val != 0 /*== false*/ )
 	{
@@ -528,7 +522,7 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
   if( openFileManager == true )
   {
     kdDebug() << "opening filemanager" << endl;
-    if(  mStd.fileManager().isEmpty() == false ) 
+    if(  mStd.fileManager().isEmpty() == false )
     {
       QString cmd = mStd.fileManager();
       int pos = cmd.find("%m");
@@ -540,13 +534,13 @@ void KDFWidget::popupMenu( QListViewItem *item, const QPoint &p )
       {
 	cmd += " " + disk->mountPoint() +" &";
       }
-      system( cmd.latin1() );
+      system( QFile::encodeName(cmd) );
     }
   }
 
   if( position != 2 ) // No need to update when just opening the fm.
   {
-    updateDF(); 
+    updateDF();
   }
 }
 
@@ -584,7 +578,7 @@ void KDFWidget::updateDiskBarPixmaps( void )
     // never called.
     //
     //int pos=mDiskList->find(disk);
-    
+
     DiskEntry dummy(it->text(deviceCol));
     dummy.setMountPoint(it->text(mntCol));
     int pos = -1;
@@ -610,8 +604,8 @@ void KDFWidget::updateDiskBarPixmaps( void )
     if( disk->mounted() == true && disk->percentFull() != -1 )
     {
       int w = mList->columnWidth(usageCol)-2;
-      if( w <= 0 ) { continue; } 
-  
+      if( w <= 0 ) { continue; }
+
       QPixmap *pix = new QPixmap( w, h );
       if( pix == 0 ) { continue; }
 
@@ -631,7 +625,7 @@ void KDFWidget::updateDiskBarPixmaps( void )
 		 pix->height()-2);
       it->setPixmap ( usageCol, *pix );
       p.end();
-      delete pix; 
+      delete pix;
     }
   }
 }
