@@ -19,22 +19,21 @@
  */
 
 #include <ctype.h>
-#include <iostream.h>
+#include <iostream>
 #include <values.h>
 
 #include <qbuttongroup.h> 
 #include <qfileinfo.h> 
 #include <qlayout.h> 
-#include <qsize.h>
 #include <qvalidator.h> 
 
-#include <kapp.h>
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kmessagebox.h> 
 #include <kseparator.h>
 
 #include "dialog.h"
+#include <qpushbutton.h>
 
 static const QStringList &formatStrings( void );
 static const QStringList &operationStrings( void );
@@ -242,6 +241,7 @@ CFindDialog::CFindDialog( QWidget *parent, const char *name, bool modal )
   uint val = config.readUnsignedNumEntry( "Format", 0 );
   mSelector->setCurrentItem(QMIN(4,val) );
   selectorChanged( mSelector->currentItem() );
+  enableButtonOK(!mInput->text().isEmpty());
 }
 
 
@@ -272,6 +272,7 @@ void CFindDialog::inputChanged( const QString &text )
   mFindString[ mSelector->currentItem() ] = text;
   mFindValidator->convert( mFindData, 
     mFindString[ mSelector->currentItem() ] );
+  enableButtonOK(!text.isEmpty());
 }
 
 
@@ -590,6 +591,7 @@ CReplaceDialog::CReplaceDialog( QWidget *parent, const char *name, bool modal )
   val = config.readUnsignedNumEntry( "ReplaceFormat", 0 );
   mReplaceSelector->setCurrentItem(QMIN(4,val) );
   replaceSelectorChanged( mReplaceSelector->currentItem() );
+  enableButtonOK(!mFindInput->text().isEmpty());
 }
 
 
@@ -621,6 +623,7 @@ void CReplaceDialog::findInputChanged( const QString &text )
   mFindString[ mFindSelector->currentItem() ] = text;
   mFindValidator->convert( mFindData, 
     mFindString[ mFindSelector->currentItem() ] );
+  enableButtonOK(!text.isEmpty());
 }
 
 
@@ -1352,14 +1355,14 @@ bool verifyFileDestnation( QWidget *parent, const QString &title,
 
 
 
-bool stringToOffset( const char *text, uint &offset )
+bool stringToOffset( const QString & text, uint &offset )
 {
-  if( text == 0 || strlen(text) == 0 )
+  if( text.isEmpty() )
   {
     return( false );
   }
 
-  const char *p = text;
+  const char * p = text.ascii(); // ####: Is this correct?
 
   //
   // Skip any whitespaces in front of string
@@ -1445,3 +1448,4 @@ static const QStringList &operationStrings( void )
 
 
 
+#include "dialog.moc"
