@@ -19,35 +19,28 @@
  */
 
 
-#include <qhbox.h>
 #include <qvbox.h>
-#include <qvbuttongroup.h> 
-
+#include <qvbuttongroup.h>
+#include <qpainter.h>
 
 #include <values.h>
 
-#include <qbuttongroup.h>
 #include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qfont.h>
-#include <qframe.h>
 #include <qlayout.h>
 #include <qlabel.h>
-#include <qlineedit.h> 
-#include <qpushbutton.h>
 #include <qradiobutton.h>
 #include <qspinbox.h>
 
-#include <kapp.h>
-#include <kcolordlg.h>
+#include <kcolordialog.h>
 #include <kcolordrag.h>
-#include <kconfig.h>
 #include <kfontdialog.h> // For KFontChooser
 #include <kiconloader.h>
 #include <klocale.h>
 
 
 #include "optiondialog.h"
+#include <qpushbutton.h>
+#include <qcombobox.h>
 
 #if 0
 #include <qobjectlist.h>
@@ -104,10 +97,10 @@ void COptionDialog::setupLayoutPage( void )
   QString text;
   QFrame *page = addPage( i18n("Layout"), i18n("Data layout in editor"),
 			  BarIcon("khexedit", KIcon::SizeMedium ) );
-  
+
   QGridLayout *gbox = new QGridLayout( page, 15, 2, 0, spacingHint() );
   gbox->setColStretch( 1, 10 );
- 
+
   mLayout.formatCombo  = new QComboBox( false, page );
   QStringList modeList;
   modeList.append( i18n("Hexadecimal mode") );
@@ -116,7 +109,7 @@ void COptionDialog::setupLayoutPage( void )
   modeList.append( i18n("Binary mode") );
   modeList.append( i18n("Text only mode") );
   mLayout.formatCombo->insertStringList( modeList );
-  connect( mLayout.formatCombo, SIGNAL(activated(int)), 
+  connect( mLayout.formatCombo, SIGNAL(activated(int)),
 	   SLOT(slotModeSelectorChanged(int)) );
   gbox->addWidget( mLayout.formatCombo, 0, 1 );
 
@@ -127,13 +120,13 @@ void COptionDialog::setupLayoutPage( void )
   mLayout.lineSizeSpin = new QSpinBox( page );
   mLayout.lineSizeSpin->setMinimumWidth( fontMetrics().width("M") * 10 );
   mLayout.lineSizeSpin->setRange( 1, 10000 );
-  connect( mLayout.lineSizeSpin, SIGNAL(valueChanged(int)), 
+  connect( mLayout.lineSizeSpin, SIGNAL(valueChanged(int)),
 	   SLOT(slotLineSizeChanged(int) ) );
   gbox->addWidget( mLayout.lineSizeSpin, 1, 1 );
 
   mLayout.columnSizeSpin = new QSpinBox( page );
   mLayout.columnSizeSpin->setRange( 1, 10000 );
-  connect( mLayout.columnSizeSpin, SIGNAL(valueChanged(int)), 
+  connect( mLayout.columnSizeSpin, SIGNAL(valueChanged(int)),
 	   SLOT(slotColumnSizeChanged(int) ) );
   gbox->addWidget( mLayout.columnSizeSpin, 2, 1 );
 
@@ -149,11 +142,11 @@ void COptionDialog::setupLayoutPage( void )
   hline->setFrameStyle( QFrame::Sunken | QFrame::HLine );
   gbox->addMultiCellWidget( hline, 3, 3, 0, 1 );
 
-  text = i18n("Line size is &fixed (use scrollbar when required)"); 
+  text = i18n("Line size is &fixed (use scrollbar when required)");
   mLayout.lockLineCheck = new QCheckBox( text, page );
   gbox->addMultiCellWidget( mLayout.lockLineCheck, 4, 4, 0, 1, AlignLeft );
 
-  text = i18n("Loc&k column at end of line (when column size > 1)"); 
+  text = i18n("Loc&k column at end of line (when column size > 1)");
   mLayout.lockColumnCheck = new QCheckBox( text, page );
   gbox->addMultiCellWidget( mLayout.lockColumnCheck, 5, 5, 0, 1 );
 
@@ -170,7 +163,7 @@ void COptionDialog::setupLayoutPage( void )
   mLayout.gridCombo = new QComboBox( false, page );
   mLayout.gridCombo->insertStringList( gridList );
 
-  text = i18n("&Gridlines between text"); 
+  text = i18n("&Gridlines between text");
   label = new QLabel( mLayout.gridCombo, text, page );
 
   gbox->addWidget( label, 7, 0 );
@@ -207,16 +200,16 @@ void COptionDialog::setupLayoutPage( void )
   text = i18n("&Edge margin width [pixels]");
   label = new QLabel( mLayout.edgeSpin, text, page );
   gbox->addWidget( label, 11, 0 );
- 
+
   text = i18n("Column separation is e&qual to one character");
   mLayout.columnCheck = new QCheckBox( text, page );
   gbox->addMultiCellWidget( mLayout.columnCheck, 12, 12, 0, 1, AlignLeft );
   connect( mLayout.columnCheck, SIGNAL(toggled(bool)),
 	   SLOT( slotColumnSepCheck(bool)));
- 
+
   mLayout.columnSepSpin = new QSpinBox( page );
   mLayout.columnSepSpin->setRange( 1, 100 );
- 
+
   text = i18n("Column separa&tion [pixels]");
   mLayout.columnSepLabel = new QLabel( mLayout.columnSepSpin, text, page );
 
@@ -231,7 +224,7 @@ void COptionDialog::setupCursorPage( void )
 {
   QString text;
   QFrame *page = addPage( i18n("Cursor"),
-    i18n("Cursor behavior. Only valid for editor"), 
+    i18n("Cursor behavior. Only valid for editor"),
     BarIcon("mouse", KIcon::SizeMedium ) );
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
 
@@ -282,8 +275,8 @@ void COptionDialog::setupCursorPage( void )
 void COptionDialog::setupColorPage( void )
 {
   QString text;
-  QFrame *page = addPage( i18n("Colors"), 
-    i18n("Editor colors. System selection color is always used"), 
+  QFrame *page = addPage( i18n("Colors"),
+    i18n("Editor colors. System selection color is always used"),
     BarIcon("colorize", KIcon::SizeMedium ) );
 
   QVBoxLayout *topLayout = new QVBoxLayout( page, 0, spacingHint() );
@@ -331,7 +324,7 @@ void COptionDialog::setupColorPage( void )
 void COptionDialog::setupFontPage( void )
 {
   QString text;
-  QFrame *page = addPage( i18n("Font"), 
+  QFrame *page = addPage( i18n("Font"),
     i18n("Font selection. Editor can only use a fixed font"),
     BarIcon("fonts", KIcon::SizeMedium ) );
 
@@ -342,7 +335,7 @@ void COptionDialog::setupFontPage( void )
   connect( mFont.checkSystem, SIGNAL(toggled(bool)),
 	   this, SLOT( slotFontSystem(bool)));
   topLayout->addWidget( mFont.checkSystem );
-  
+
   QFrame *hline = new QFrame( page );
   hline->setFrameStyle( QFrame::Sunken | QFrame::HLine );
   topLayout->addWidget( hline );
@@ -361,10 +354,10 @@ void COptionDialog::setupFontPage( void )
 
   mFont.nonPrintInput = new QLineEdit( page );
   mFont.nonPrintInput->setMaxLength( 1 );
- 
+
   text = i18n("&Map non printable characters to:");
   QLabel *nonPrintLabel = new QLabel( mFont.nonPrintInput, text, page );
-  
+
   hbox->addWidget( nonPrintLabel, 0, AlignLeft );
   hbox->addSpacing( spacingHint() );
   hbox->addWidget( mFont.nonPrintInput, 10 );
@@ -425,8 +418,8 @@ void COptionDialog::setupFilePage( void )
   text = i18n("Don't &save \"Recent\" document list on exit");
   mFile.discardRecentCheck = new QCheckBox( text, page );
   topLayout->addWidget( mFile.discardRecentCheck, 0, AlignLeft );
- 
-  text = i18n("Clear \"Recent\" document list &now");
+
+  text = i18n("Clear \"Recent\" Document List &Now");
   QPushButton *discardRecentButton = new QPushButton( page );
   discardRecentButton->setText( text );
   topLayout->addWidget( discardRecentButton, 0, AlignCenter );
@@ -437,14 +430,12 @@ void COptionDialog::setupFilePage( void )
 }
 
 
-#include <kinstance.h>
-#include <kglobal.h>
 
 void COptionDialog::setupMiscPage( void )
 {
   QString text;
   QLabel *label;
-  
+
   QFrame *page = addPage( i18n("Miscellaneous"), i18n("Various properties"),
 			  BarIcon("gear", KIcon::SizeMedium ) );
 
@@ -501,14 +492,14 @@ void COptionDialog::setupMiscPage( void )
 
   text = i18n("&Threshold [pages]" );
   mMisc.thresholdLabel = new QLabel( mMisc.thresholdSpin, text, page );
-  
+
   glay->addWidget( mMisc.thresholdLabel, 0, 0 );
   glay->addWidget( mMisc.thresholdSpin, 0, 1 );
 
   QFrame *hline = new QFrame( page );
   hline->setFrameStyle( QFrame::Sunken | QFrame::HLine );
   glay->addMultiCellWidget( hline, 1, 1, 0, 2 );
-  
+
   mMisc.undoSpin = new QSpinBox( page );
   mMisc.undoSpin->setRange( 10, 10000 );
   mMisc.undoSpin->setSteps( 5, 5 );
@@ -535,9 +526,9 @@ void COptionDialog::slotLineSizeChanged( int value )
 {
   int index = mLayout.formatCombo->currentItem();
   mDisplayState.line.setLineSize( index, value );
-  if( index == SDisplayLine::textOnly ) 
-  { 
-    mLayout.columnSizeSpin->setValue( value ); 
+  if( index == SDisplayLine::textOnly )
+  {
+    mLayout.columnSizeSpin->setValue( value );
   }
 }
 
@@ -545,9 +536,9 @@ void COptionDialog::slotColumnSizeChanged( int value )
 {
   int index = mLayout.formatCombo->currentItem();
   mDisplayState.line.setColumnSize( index, value );
-  if( index == SDisplayLine::textOnly ) 
-  { 
-    mLayout.lineSizeSpin->setValue( value ); 
+  if( index == SDisplayLine::textOnly )
+  {
+    mLayout.lineSizeSpin->setValue( value );
   }
 }
 
@@ -580,7 +571,7 @@ void COptionDialog::slotFontSystem( bool state )
 void COptionDialog::slotColorSystem( bool state )
 {
   state = state == true ? false : true;
-  mColor.colorList->setEnabled( state ); 
+  mColor.colorList->setEnabled( state );
 }
 
 
@@ -602,8 +593,8 @@ void COptionDialog::slotDefault( void )
   {
     case page_layout:
     {
-      SDisplayLayout layout; 
-      SDisplayLine line; 
+      SDisplayLayout layout;
+      SDisplayLine line;
       setLayout( layout, line );
     }
     break;
@@ -701,7 +692,7 @@ void COptionDialog::slotApply( void )
 
     case page_cursor:
     {
-      SDisplayCursor &c = mDisplayState.cursor;      
+      SDisplayCursor &c = mDisplayState.cursor;
       c.alwaysVisible    = mCursor.blinkCheck->isChecked();
       c.interval         = mCursor.blinkSpin->value();
       c.alwaysBlockShape = mCursor.blockCheck->isChecked();
@@ -743,7 +734,7 @@ void COptionDialog::slotApply( void )
       f.useSystemFont = mFont.checkSystem->isChecked();
       f.localFont = mFont.chooser->font();
 
-      QString nonPrintText = mFont.nonPrintInput->text(); 
+      QString nonPrintText = mFont.nonPrintInput->text();
       if( nonPrintText.isEmpty() )
       {
 	f.nonPrintChar = ' ';
@@ -800,7 +791,7 @@ void COptionDialog::setLayout( SDisplayLayout &layout, SDisplayLine &line )
   mLayout.edgeSpin->setValue( layout.edgeMarginWidth );
   mLayout.leftSepWidthSpin->setValue( layout.leftSeparatorWidth );
   mLayout.rightSepWidthSpin->setValue( layout.rightSeparatorWidth );
-  mLayout.columnCheck->setChecked( layout.columnCharSpace ); 
+  mLayout.columnCheck->setChecked( layout.columnCharSpace );
   slotColumnSepCheck( layout.columnCharSpace );
   mLayout.columnSepSpin->setValue( layout.columnSpacing );
 
@@ -823,7 +814,7 @@ void COptionDialog::setLayout( SDisplayLayout &layout, SDisplayLine &line )
 void COptionDialog::setCursor( SDisplayCursor &cursor )
 {
   mDisplayState.cursor = cursor;
- 
+
   mCursor.blinkCheck->setChecked( cursor.alwaysVisible );
   mCursor.blinkSpin->setValue( cursor.interval );
   mCursor.blockCheck->setChecked( cursor.alwaysBlockShape );
@@ -882,7 +873,7 @@ void COptionDialog::setMisc( SDisplayMisc &misc )
   mDisplayState.misc.insertMode           = misc.insertMode;
   mDisplayState.misc.confirmWrap          = misc.confirmWrap;
   mDisplayState.misc.cursorJump           = misc.cursorJump;
-  mDisplayState.misc.confirmThreshold     = misc.confirmThreshold; 
+  mDisplayState.misc.confirmThreshold     = misc.confirmThreshold;
   mDisplayState.misc.thresholdValue       = misc.thresholdValue;
   mDisplayState.misc.bookmarkOffsetColumn = misc.bookmarkOffsetColumn;
   mDisplayState.misc.bookmarkEditor       = misc.bookmarkEditor;
@@ -977,12 +968,12 @@ void CColorListBox::setEnabled( bool state )
 void CColorListBox::setColor( uint index, const QColor &color )
 {
   if( index < count() )
-  { 
+  {
     CColorListItem *colorItem = (CColorListItem*)item(index);
     colorItem->setColor(color);
     updateItem( colorItem );
   }
-} 
+}
 
 
 const QColor CColorListBox::color( uint index )
@@ -999,7 +990,7 @@ const QColor CColorListBox::color( uint index )
 }
 
 
-void CColorListBox::newColor( int index ) 
+void CColorListBox::newColor( int index )
 {
   if( isEnabled() == false )
   {
@@ -1032,7 +1023,7 @@ void CColorListBox::dragEnterEvent( QDragEnterEvent *e )
 }
 
 
-void CColorListBox::dragLeaveEvent( QDragLeaveEvent * ) 
+void CColorListBox::dragLeaveEvent( QDragLeaveEvent * )
 {
   if( mCurrentOnDragEnter != -1 )
   {
@@ -1044,7 +1035,7 @@ void CColorListBox::dragLeaveEvent( QDragLeaveEvent * )
 
 void CColorListBox::dragMoveEvent( QDragMoveEvent *e )
 {
-  if( KColorDrag::canDecode(e) && isEnabled() ) 
+  if( KColorDrag::canDecode(e) && isEnabled() )
   {
     CColorListItem *item = (CColorListItem*)itemAt( e->pos() );
     if( item != 0 )
@@ -1058,7 +1049,7 @@ void CColorListBox::dragMoveEvent( QDragMoveEvent *e )
 void CColorListBox::dropEvent( QDropEvent *e )
 {
   QColor color;
-  if( KColorDrag::decode( e, color ) ) 
+  if( KColorDrag::decode( e, color ) )
   {
     int index = currentItem();
     if( index != -1 )
